from setuptools import setup

setup(
    name='japanese',
    version='0.1',
    descrption='Python Japanese library for Humans',
    url='https://github.com/kekeho/japanese',
    author='Hiroki Takemura',
    author_email='hirodora@me.com',
    license='MIT',
    keywords='japanese utils util',
    packages=["japanese",],
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Natural Language :: Japanese'
    ]
)